.. role:: hidden
    :class: hidden-section

ax.modelbridge
===================================

.. automodule:: ax.modelbridge
.. currentmodule:: ax.modelbridge


Generation Strategy, Registry, and Factory
-------------------------------------------

Generation Strategy
~~~~~~~~~~~~~~~~~~~~
.. automodule:: ax.modelbridge.generation_strategy
    :members:
    :undoc-members:
    :show-inheritance:

Generation Node
~~~~~~~~~~~~~~~
.. automodule:: ax.modelbridge.generation_node
    :members:
    :undoc-members:
    :show-inheritance:

Completion Criterion
.. automodule:: ax.modelbridge.completion_criterion
    :members:
    :undoc-members:
    :show-inheritance:

Registry
~~~~~~~~~~~~~~~~~~~~
.. automodule:: ax.modelbridge.registry
    :members:
    :undoc-members:
    :show-inheritance:

Factory
~~~~~~~~~~~~~~~~~~~~~
.. automodule:: ax.modelbridge.factory
    :members:
    :undoc-members:
    :show-inheritance:

ModelSpec
~~~~~~~~~
.. automodule:: ax.modelbridge.model_spec
    :members:
    :undoc-members:
    :show-inheritance:

Model Bridges
--------------

Base Model Bridge
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.base
    :members:
    :undoc-members:
    :show-inheritance:

Discrete Model Bridge
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.discrete
    :members:
    :undoc-members:
    :show-inheritance:

Random Model Bridge
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.random
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

Torch Model Bridge
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.torch
    :members:
    :undoc-members:
    :show-inheritance:

Pairwise Model Bridge
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.pairwise
    :members:
    :undoc-members:
    :show-inheritance:

Map Torch Model Bridge
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.map_torch
    :members:
    :undoc-members:
    :show-inheritance:

Utilities
---------------

General Utilities
~~~~~~~~~~~~~~~~~~
.. automodule:: ax.modelbridge.modelbridge_utils
    :members:
    :undoc-members:
    :show-inheritance:

Prediction Utilities
~~~~~~~~~~~~~~~~~~
.. automodule:: ax.modelbridge.prediction_utils
    :members:
    :undoc-members:
    :show-inheritance:

Cross Validation
~~~~~~~~~~~~~~~~~
.. automodule:: ax.modelbridge.cross_validation
    :members:
    :undoc-members:
    :show-inheritance:

Dispatch Utilities
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.dispatch_utils
    :members:
    :undoc-members:
    :show-inheritance:

Transforms
-------------

`ax.modelbridge.transforms.base`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.base
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.cast`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.cast
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.cap_parameter`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.cap_parameter
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.centered_unit_x`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.centered_unit_x
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.choice\_encode`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.choice_encode
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.convert_metric_names`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.convert_metric_names
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.derelativize`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.derelativize
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.int\_range\_to\_choice`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.int_range_to_choice
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.int\_to\_float`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.int_to_float
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.ivw`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.ivw
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.inverse_gaussian_cdf_y`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.inverse_gaussian_cdf_y
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.log`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.log
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.log_y`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.log_y
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.logit`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.logit
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.map_unit_x`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.map_unit_x
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.metrics_as_task`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.metrics_as_task
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.one\_hot`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.one_hot
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.percentile_y`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.percentile_y
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.power\_transform\_y`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.power_transform_y
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.remove\_fixed`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.remove_fixed
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.rounding`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.rounding
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.search\_space\_to\_choice`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.search_space_to_choice
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.standardize\_y`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.standardize_y
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.stratified\_standardize\_y`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.stratified_standardize_y
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.task\_encode`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.task_encode
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.trial\_as\_task`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.trial_as_task
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.unit\_x`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.unit_x
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.utils`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.utils
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.winsorize`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.winsorize
    :members:
    :undoc-members:
    :show-inheritance:

`ax.modelbridge.transforms.relativize`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.transforms.relativize
    :members:
    :undoc-members:
    :show-inheritance:

Strategies
-------------

`ax.modelbridge.strategies.alebo`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.modelbridge.strategies.alebo
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: ax.modelbridge.strategies.rembo
    :members:
    :undoc-members:
    :show-inheritance:
